<?php

/* Event Booking Pro - WordPress Plugin
 * Form Manager Addon
 * Get plugin at: http://iplusstd.com/item/eventBookingPro/
 * Author Moe Haydar
 */


class EventBookingFormsAdmin {

	var $main, $path, $name, $url;
	function __construct($file) {
		$this->main = $file;
		$this->version = "1.41";
		$this->init();
		return $this;
	}

	function init() {
		$this->path = dirname( __FILE__ );
		$this->name = basename( $this->path );
		$this->url = plugins_url( "/{$this->name}/" );

		$this->hasCharegableInputs = EventBookingFormsAdmin::checkForExtra(false);

		if (is_admin()) {
			register_activation_hook( $this->main , array(&$this, 'activate') );
			register_deactivation_hook($this->main , array(&$this, 'deactivate') );
			add_action('wp_ajax_form_save', array(&$this, 'saveForm'));
			add_action('wp_ajax_form_fetch', array(&$this, 'getForm'));
			add_action('wp_ajax_form_delete', array(&$this, 'deleteForm'));
			add_action('admin_menu', array(&$this, 'admin_menu'));
		}
	}

	function getTableName($name) {
		global $wpdb;

		$tables = array(
			'forms' => $wpdb->base_prefix . 'ebp_forms',
			'formsInput' => $wpdb->base_prefix . 'ebp_forms_inputs'
		);

    return (string) $tables[$name];
  }

	function deactivate(){
		update_option("ev_uses_form", "0");
	}

	function activate() {
		global $wpdb;
		require_once(ABSPATH . 'wp-admin/includes/upgrade.php');

		$formsTable = $this->getTableName("forms");
		$formsTable_sql = "CREATE TABLE " . $formsTable ." (
					  id INT NOT NULL AUTO_INCREMENT,
					  name varchar(100) NOT NULL,
					  splitName varchar(7) default 'false',
					  firstNameTxt varchar(100) default 'First Name',
					  lastNameTxt varchar(100) default 'Last Name',
					  PRIMARY KEY (id)
					);";


		$formsInputTable = $this->getTableName("formsInput");
		$formsInput_sql = "CREATE TABLE " . $formsInputTable ." (
					  id INT NOT NULL AUTO_INCREMENT,
					  form INT NOT NULL,
					  type varchar(100) NOT NULL,
					  name varchar(255) default '',
					  fieldorder int NOT NULL,
					  label varchar(255) default '',
					  required varchar(6) default 'false',
					  options TEXT,
					  prices TEXT,
					  feeType varchar(10) default 'none',
					  PRIMARY KEY (id)
					);";
		// feeType (once, ticker, none)
		dbDelta($formsTable_sql);
		dbDelta($formsInput_sql);

		update_option("ebp_forms_version", $this->version);
		update_option("ev_uses_form", "1");
	}

	function admin_menu() {
		$mainMenu = add_submenu_page( 'eventManagement','Event Booking Forms Manager', 'Forms Manager', 'manage_options', 'eventManagementForms', array(&$this, 'admin_page'),$this->url."/images/icon.png");
		add_action('load-'.$mainMenu, array(&$this, 'admin_menu_scripts'));
		add_action('load-'.$mainMenu, array(&$this, 'admin_menu_styles'));
	}

	function admin_menu_scripts() {
		wp_enqueue_script('ebp-forms-admin-js', $this->url . 'js/admin.js', array('jquery', 'jquery-ui-core', 'jquery-ui-sortable') );
	}

	function admin_menu_styles() {
		wp_enqueue_style( 'ebp-forms-admin-css', $this->url . 'css/admin.css' );
	}

	function deleteForm(){
		global $wpdb;
		$table_name = $this->getTableName("forms");
		$wpdb->delete( $table_name, array( 'id' => $_POST['id'] ), array( '%d' ) );
		echo $_POST['id'];
		die();
	}

	function getForm(){
		global $wpdb;
		$id = $_POST['id'];
		$result = $wpdb->get_row( "SELECT * FROM " . $this->getTableName("forms")." where id='$id' ");
		$result->fields=$this->getFields($id);
		if ($result != NULL) {
			echo json_encode($result);
		} else {
			echo "Error";
		}
		die();
	}

	function getFields($id){
		global $wpdb;
		$results = $wpdb->get_results( "SELECT * FROM " . $this->getTableName("formsInput")." where form='$id' order by fieldorder");
		$inputs = '';
		foreach($results as $result){
			$inputs .= $result->id;
			$inputs .= ",".$result->type;
			$inputs .= ",".$result->fieldorder;
			$inputs .= ",".$result->name;
			$inputs .= ",".$result->label;
			$inputs .= ",".$result->required;
			$inputs .= ",".$result->options;
			$inputs .= ",".$result->prices;
			$inputs .= ",".$result->feeType;
			$inputs .= "|";
		}
		return $inputs;
	}

	function saveForm() {
		global $wpdb;
		$table_name =$this->getTableName("forms");


		$id = $_POST['id'];
		$name = $_POST['name'];

		$splitName = $_POST['splitName'];
		$firstNameTxt = $_POST['firstNameTxt'];
		$lastNameTxt = $_POST['lastNameTxt'];

		$extras = $_POST['extras'];

		$isAvilable = $wpdb->get_var( "select COUNT(*) from " . $table_name ." where id= '$id'");

		$data = array('name'=>$name, 'splitName'=>$splitName , 'firstNameTxt'=>$firstNameTxt, 'lastNameTxt'=>$lastNameTxt);

		if ($isAvilable > 0) {
			$wpdb->update($table_name, $data, array( 'id' => $id ));
		} else {
			$data['id'] = $id;
			$wpdb->insert($table_name ,$data);
		}

		$occurIds = array();
		$split = explode( '|', $extras );
		foreach ($split as $one) {
			$final = explode( ',', $one );
			$final[0] = $this->addFormInput($id, $final);
			array_push($occurIds,$final[0]);
		}

		//delete those deleted
		$results = $wpdb->get_results("SELECT * FROM " .$this->getTableName("formsInput")." where form='$id'");
		foreach($results as $result){
			if(!in_array($result->id, $occurIds))
				$wpdb->delete( $this->getTableName("formsInput"), array( 'id' => $result->id ), array( '%d' ) );
		}

		die();
	}

	function addFormInput($id, $final){
		global $wpdb;
		$table_name = $this->getTableName("formsInput");

		$data = array('type'=>$final[1], 'name'=>$final[3], 'fieldorder'=>$final[2], 'label'=>$final[4], 'required'=>$final[5], 'options'=>$final[6]);

		if ($this->hasCharegableInputs) {
			$data['prices'] = $final[7];
			$data['feeType'] = $final[8];
		}

		if($final[0] != "-1"){
			$wpdb->update($table_name, $data , array("id"=>$final[0]));
			$newId = $final[0];
		} else {
			$data['form'] = $id;
			$wpdb->insert($table_name, $data);
			$newId = $wpdb->insert_id;
		}

		return $newId;
	}

	function admin_page() {
		include_once($this->path . '/pages/admin.php');
	}

	static function checkForExtra($html = true) {
		if (get_option('ev_uses_form_extra') != 1) return;

		$val = false;
		if (!class_exists("eventBookingProFormExtrasAdmin")) {

			$addonPath = dirname( __FILE__ ).'/eventBookingProFormExtras/eventBookingProFormExtrasClass.php';
			if (is_file($addonPath)) {
				require_once($addonPath);
				$val = true;
			}
		} else {
			$val = true;
		}


		if ($html && $val) {
			return eventBookingProFormExtrasAdmin::usesExtraHTML();
		} else if (!$html) {
			return $val;
		}
	}
}

